#!/bin/bash

#https://github.com/tensorflow/models/tree/master/slim

# Usage:
# cd slim
# sh train-alexnet.sh <dataset_dir> <dataset> <rankfile>
# Example: sh train-alexnet.sh /mnt/glusterfs/GVolDist1/DEEPLEARN/tensorflow/data imagenet rf_4x2_hosts 

if  [ $# != 3 ]
then
    echo "Usage: sh train-alexnet.sh <dataset_dir> <dataset> <rankfile>"
    echo "Example: sh train-alexnet.sh /mnt/glusterfs/GVolDist1/DEEPLEARN/tensorflow/data imagenet rf_4x2_hosts"
    exit 1
fi


# What is the top-level/root directory of all data sets?
DATASET_DIR=$1

# What is the name of the dataset? (Must be a directory under DATASET_DIR)
DATASET=$2

# Note: we use the same preprocessing as with inception_v3!
RANKFILE=$3

#Name of the model/network (Must be in models/slim/nets)
MODEL=alexnet_v2

# Where should the summaries etc. be logged? (Must be a writable directory)
TRAIN_DIR=/tmp/${MODEL}_logs

# Note: TF 1.1.0 requires devices with CUDA compute capability 6.0

# Execute the slim train script with the proper cmdline arguments,
# possibly under control of MPI:

#mpirun -x LD_LIBRARY_PATH -x PATH -x PYTHONPATH -n 12 -rf <rankfile> \
#mpirun -x LD_LIBRARY_PATH -x PATH -x PYTHONPATH -n 8 -host <list of hosts> \
mpirun -x LD_LIBRARY_PATH -x PATH -x PYTHONPATH -n 8 -rf ${RANKFILE} \
python train_image_classifier.py \
    --train_dir=${TRAIN_DIR} \
    --dataset_name=${DATASET} \
    --dataset_split_name=train \
    --dataset_dir=${DATASET_DIR}/${DATASET} \
    --model_name=${MODEL} \
    --max_number_of_steps=2000 \
    --log_every_n_steps=100 \
    --optimizer=sgd \
    --batch_size=16 \
    --num_readers=4 \
    --num_preprocessing_threads=4 \
    --preprocessing_name=inception

#    --preprocessing_name=cifarnet \
#    --save_interval_secs=120 \
#    --save_summaries_secs=120 \
#    --learning_rate=0.1 \
#    --learning_rate_decay_factor=0.1 \
#    --num_epochs_per_decay=200 \
#    --weight_decay=0.004
