#!/bin/bash

#https://github.com/tensorflow/models/tree/master/slim

# Usage:
# cd slim
# sh train-cifar10.sh <dataset_dir> <dataset> <list_of_hosts>
# Example: sh train-cifar10.sh /mnt/glusterfs/GVolDist1/DEEPLEARN/tensorflow/data cifar10 host1,host2,host3,host4

if  [ $# != 3 ]
then
    echo "Usage: sh train-cifar10.sh <dataset_dir> <dataset> <list_of_hosts>"
    echo "Example: sh train-cifar10.sh /mnt/glusterfs/GVolDist1/DEEPLEARN/tensorflow/data cifar10 host1,host2,host3,host4"
    exit 1
fi

# What is the top-level/root directory of all data sets?
DATASET_DIR=$1

#What is the name of the dataset? (Must be a directory under DATASET_DIR)
DATASET=$2

#Name of the model/network (Must be in models/slim/nets)
MODEL=cifarnet

# Where should the summaries etc. be logged? (Must be a writable directory)
TRAIN_DIR=/tmp/${MODEL}_logs

#Comma separated list of hosts
HOSTS=$3

# Note: TF 1.1.0 requires devices with CUDA compute capability 6.0

# Execute the slim train script with the proper cmdline arguments,
# possibly under control of MPI:

mpirun -x LD_LIBRARY_PATH -x PATH -x PYTHONPATH -n 4 -host ${HOSTS} \
python train_image_classifier.py \
    --train_dir=${TRAIN_DIR} \
    --dataset_name=${DATASET} \
    --dataset_split_name=train \
    --dataset_dir=${DATASET_DIR}/${DATASET} \
    --model_name=${MODEL} \
    --max_number_of_steps=1000 \
    --log_every_n_steps=100 \
    --optimizer=sgd \
    --batch_size=128 \
    --num_readers=1 \
    --num_preprocessing_threads=1

#    --num_clones=2

#    --preprocessing_name=cifarnet \
#    --save_interval_secs=120 \
#    --save_summaries_secs=120 \
#    --learning_rate=0.1 \
#    --learning_rate_decay_factor=0.1 \
#    --num_epochs_per_decay=200 \
#    --weight_decay=0.004
