#!/bin/bash

#https://github.com/tensorflow/models/tree/master/slim

# Make sure PATH and LD_LIBRARY_PATH are correctly set up
# - mpirun is needed
# - CUDA and NCCL libraries are needed
# - IBM PowerAI Distributed Deep Learning (DDL) TF (ddl_MDR.so) library is needed
# - Know where the data is
# - Run inside a Python virtual environment with Tensorflow
# - git clone https://github.com/tensorflow/models.git

# Usage:
# cd models/slim
# sh train-inception_v3.sh <dataset_dir> <dataset> <list_of_hosts>
# Example: sh train-inception_v3.sh /mnt/glusterfs/GVolDist1/DEEPLEARN/tensorflow/data imagenet host1,host2,host3,host4

if  [ $# != 3 ]
then
    echo "Usage: sh train-inception_v3.sh <dataset_dir> <dataset> <list_of_hosts>"
    echo "Example: sh train-inception_v3.sh /mnt/glusterfs/GVolDist1/DEEPLEARN/tensorflow/data imagenet host1,host2,host3,host4"
    exit 1
fi

# What is the top-level/root directory of all data sets?
DATASET_DIR=$1

# What is the name of the dataset? (Must be a directory under DATASET_DIR)
DATASET=$2

#Name of the model/network (Must be in models/slim/nets)
MODEL=inception_v3

# Comma separated list of hosts
HOSTS=$3

# Where should the summaries etc. be logged? (Must be a writable directory)
TRAIN_DIR=/tmp/${MODEL}_logs

# Note: TF 1.1.0 requires devices with CUDA compute capability 6.0

# Execute the slim train script with the proper cmdline arguments,
# possibly under control of MPI:

mpirun -x LD_LIBRARY_PATH -x PATH -x PYTHONPATH -n 4 -host ${HOSTS} \
python train_image_classifier.py \
    --train_dir=${TRAIN_DIR} \
    --dataset_name=${DATASET} \
    --dataset_split_name=train \
    --dataset_dir=${DATASET_DIR}/${DATASET} \
    --model_name=${MODEL} \
    --max_number_of_steps=2000 \
    --log_every_n_steps=100 \
    --optimizer=sgd \
    --batch_size=16 \
    --num_readers=1 \
    --num_preprocessing_threads=1

# Additional options (and more see inside train_image_classifier.py)
#    --preprocessing_name=cifarnet \
#    --save_interval_secs=120 \
#    --save_summaries_secs=120 \
#    --learning_rate=0.1 \
#    --learning_rate_decay_factor=0.1 \
#    --num_epochs_per_decay=200 \
#    --weight_decay=0.004
